@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2016-2019 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -62,7 +62,10 @@ Q_GADGET
             KindInputmethod,
             KindFirmware,
             KindDriver,
-            KindLocalization
+            KindLocalization,
+            KindService,
+            KindRepository,
+            KindOperatingSystem
         };
         Q_ENUM(Kind)
 
@@ -80,7 +83,8 @@ Q_GADGET
             UrlKindFaq,
             UrlKindHelp,
             UrlKindDonation,
-            UrlTranslate
+            UrlTranslate,
+            UrlKindContact
         };
         Q_ENUM(UrlKind)
 
