@@ -18,7 +18,7 @@
  * along with this library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "as-distro-details.h"
+#include "as-distro-details-private.h"
 
 #include <glib.h>
 #include <glib-object.h>
@@ -28,6 +28,7 @@
 #include <gio/gio.h>
 
 #include "as-settings-private.h"
+#include "as-utils-private.h"
 
 /**
  * SECTION:as-distro-details
@@ -44,9 +45,12 @@
 
 typedef struct
 {
-	gchar* distro_id;
-	gchar* distro_name;
-	gchar* distro_version;
+	gchar *id;
+	gchar *cid;
+	gchar *name;
+	gchar *version;
+	gchar *homepage;
+
 	GKeyFile* keyf;
 } AsDistroDetailsPrivate;
 
@@ -57,47 +61,75 @@ enum  {
 	AS_DISTRO_DETAILS_DUMMY_PROPERTY,
 	AS_DISTRO_DETAILS_ID,
 	AS_DISTRO_DETAILS_NAME,
-	AS_DISTRO_DETAILS_VERSION
+	AS_DISTRO_DETAILS_VERSION,
+	AS_DISTRO_DETAILS_HOMEPAGE
 };
 
-static void as_distro_details_set_id (AsDistroDetails *distro, const gchar *value);
-static void as_distro_details_set_name (AsDistroDetails *distro, const gchar *value);
-static void as_distro_details_set_version (AsDistroDetails *distro, const gchar *value);
-
 /**
  * as_distro_details_init:
  **/
 static void
 as_distro_details_init (AsDistroDetails *distro)
 {
+	as_distro_details_load_data (distro, "/etc/os-release", AS_CONFIG_NAME);
+}
+
+/**
+ * as_distro_details_finalize:
+ **/
+static void
+as_distro_details_finalize (GObject *object)
+{
+	AsDistroDetails *distro = AS_DISTRO_DETAILS (object);
+	AsDistroDetailsPrivate *priv = GET_PRIVATE (distro);
+
+	g_free (priv->id);
+	g_free (priv->name);
+	g_free (priv->version);
+	g_free (priv->homepage);
+	g_key_file_unref (priv->keyf);
+
+	G_OBJECT_CLASS (as_distro_details_parent_class)->finalize (object);
+}
+
+/**
+ * as_distro_details_load_data:
+ */
+void
+as_distro_details_load_data (AsDistroDetails *distro, const gchar *os_release_fname, const gchar *as_config_fname)
+{
+	AsDistroDetailsPrivate *priv = GET_PRIVATE (distro);
 	g_autoptr(GFile) f = NULL;
 	g_autoptr(GError) error = NULL;
 	gchar *line;
-	AsDistroDetailsPrivate *priv = GET_PRIVATE (distro);
-
-	as_distro_details_set_id (distro, "unknown");
-	as_distro_details_set_name (distro, "");
-	as_distro_details_set_version (distro, "");
 
 	/* load configuration */
+	if (priv->keyf != NULL)
+		g_key_file_unref (priv->keyf);
+
 	priv->keyf = g_key_file_new ();
-	g_key_file_load_from_file (priv->keyf, AS_CONFIG_NAME, G_KEY_FILE_NONE, NULL);
+	if (as_config_fname != NULL)
+		g_key_file_load_from_file (priv->keyf, as_config_fname, G_KEY_FILE_NONE, NULL);
 
 	/* get details about the distribution we are running on */
-	f = g_file_new_for_path ("/etc/os-release");
+	f = g_file_new_for_path (os_release_fname);
 	if (g_file_query_exists (f, NULL)) {
 		g_autoptr(GDataInputStream) dis = NULL;
 		g_autoptr(GFileInputStream) fis = NULL;
 
 		fis = g_file_read (f, NULL, &error);
-		if (error != NULL)
+		if (error != NULL) {
+			g_warning ("Unable to read %s file.", os_release_fname);
 			return;
+		}
 		dis = g_data_input_stream_new ((GInputStream*) fis);
 
 		while ((line = g_data_input_stream_read_line (dis, NULL, NULL, &error)) != NULL) {
 			g_auto(GStrv) data = NULL;
 			g_autofree gchar *dvalue = NULL;
 			if (error != NULL) {
+				g_warning ("Unable to read line in %s file.", os_release_fname);
+				g_free (line);
 				return;
 			}
 
@@ -115,35 +147,32 @@ as_distro_details_init (AsDistroDetails *distro)
 				dvalue = tmp;
 			}
 
-			if (g_strcmp0 (data[0], "ID") == 0)
-				as_distro_details_set_id (distro, dvalue);
-			else if (g_strcmp0 (data[0], "NAME") == 0)
-				as_distro_details_set_name (distro, dvalue);
-			else if (g_strcmp0 (data[0], "VERSION_ID") == 0)
-				as_distro_details_set_version (distro, dvalue);
+			if (g_strcmp0 (data[0], "ID") == 0) {
+				g_free (priv->id);
+				priv->id = g_steal_pointer (&dvalue);
+				g_object_notify ((GObject *) distro, "id");
+
+			} else if (g_strcmp0 (data[0], "NAME") == 0) {
+				g_free (priv->name);
+				priv->name = g_steal_pointer (&dvalue);
+				g_object_notify ((GObject *) distro, "name");
+
+			} else if (g_strcmp0 (data[0], "VERSION_ID") == 0) {
+				g_free (priv->version);
+				priv->version = g_steal_pointer (&dvalue);
+				g_object_notify ((GObject *) distro, "version");
+
+			} else if (g_strcmp0 (data[0], "HOME_URL") == 0) {
+				g_free (priv->homepage);
+				priv->homepage = g_steal_pointer (&dvalue);
+				g_object_notify ((GObject *) distro, "homepage");
+			}
 
 			g_free (line);
 		}
 	}
 }
 
-/**
- * as_distro_details_finalize:
- **/
-static void
-as_distro_details_finalize (GObject *object)
-{
-	AsDistroDetails *distro = AS_DISTRO_DETAILS (object);
-	AsDistroDetailsPrivate *priv = GET_PRIVATE (distro);
-
-	g_free (priv->distro_id);
-	g_free (priv->distro_name);
-	g_free (priv->distro_version);
-	g_key_file_unref (priv->keyf);
-
-	G_OBJECT_CLASS (as_distro_details_parent_class)->finalize (object);
-}
-
 /**
  * as_distro_details_get_str:
  */
@@ -155,7 +184,7 @@ as_distro_details_get_str (AsDistroDetails *distro, const gchar *key)
 
 	g_return_val_if_fail (key != NULL, NULL);
 
-	value = g_key_file_get_string (priv->keyf, priv->distro_id, key, NULL);
+	value = g_key_file_get_string (priv->keyf, priv->id, key, NULL);
 	return value;
 }
 
@@ -176,7 +205,7 @@ as_distro_details_get_bool (AsDistroDetails *distro, const gchar *key, gboolean
 		g_error_free (error);
 		error = NULL;
 
-		value = g_key_file_get_boolean (priv->keyf, priv->distro_id, key, &error);
+		value = g_key_file_get_boolean (priv->keyf, priv->id, key, &error);
 		if (error != NULL)
 			return default_val;
 	}
@@ -191,20 +220,28 @@ const gchar*
 as_distro_details_get_id (AsDistroDetails *distro)
 {
 	AsDistroDetailsPrivate *priv = GET_PRIVATE (distro);
-	return priv->distro_id;
+	return priv->id;
 }
 
 /**
- * as_distro_details_set_distro_id:
+ * as_distro_details_get_cid:
  */
-static void
-as_distro_details_set_id (AsDistroDetails *distro, const gchar *value)
+const gchar*
+as_distro_details_get_cid (AsDistroDetails *distro)
 {
 	AsDistroDetailsPrivate *priv = GET_PRIVATE (distro);
 
-	g_free (priv->distro_id);
-	priv->distro_id = g_strdup (value);
-	g_object_notify ((GObject *) distro, "id");
+	if (priv->cid != NULL)
+		return priv->cid;
+	if (priv->homepage == NULL) {
+		priv->cid = g_strdup (priv->id);
+		return priv->cid;
+	}
+
+	priv->cid = as_utils_dns_to_rdns (priv->homepage, priv->id);
+	if (priv->cid == NULL)
+		return priv->id;
+	return priv->cid;
 }
 
 /**
@@ -214,20 +251,7 @@ const gchar*
 as_distro_details_get_name (AsDistroDetails *distro)
 {
 	AsDistroDetailsPrivate *priv = GET_PRIVATE (distro);
-	return priv->distro_name;
-}
-
-/**
- * as_distro_details_set_name:
- */
-static void
-as_distro_details_set_name (AsDistroDetails *distro, const gchar *value)
-{
-	AsDistroDetailsPrivate *priv = GET_PRIVATE (distro);
-
-	g_free (priv->distro_name);
-	priv->distro_name = g_strdup (value);
-	g_object_notify ((GObject *) distro, "name");
+	return priv->name;
 }
 
 /**
@@ -237,20 +261,17 @@ const gchar*
 as_distro_details_get_version (AsDistroDetails *distro)
 {
 	AsDistroDetailsPrivate *priv = GET_PRIVATE (distro);
-	return priv->distro_version;
+	return priv->version;
 }
 
 /**
- * as_distro_details_set_version:
+ * as_distro_details_get_homepage:
  */
-static void
-as_distro_details_set_version (AsDistroDetails *distro, const gchar *value)
+const gchar*
+as_distro_details_get_homepage (AsDistroDetails *distro)
 {
 	AsDistroDetailsPrivate *priv = GET_PRIVATE (distro);
-
-	g_free (priv->distro_version);
-	priv->distro_version = g_strdup (value);
-	g_object_notify ((GObject *) distro, "version");
+	return priv->homepage;
 }
 
 /**
@@ -271,29 +292,8 @@ as_distro_details_get_property (GObject *object, guint property_id, GValue *valu
 		case AS_DISTRO_DETAILS_VERSION:
 			g_value_set_string (value, as_distro_details_get_version (distro));
 			break;
-		default:
-			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-			break;
-	}
-}
-
-/**
- * as_distro_details_set_property:
- */
-static void
-as_distro_details_set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec)
-{
-	AsDistroDetails  *distro;
-	distro = G_TYPE_CHECK_INSTANCE_CAST (object, AS_TYPE_DISTRO_DETAILS, AsDistroDetails);
-	switch (property_id) {
-		case AS_DISTRO_DETAILS_ID:
-			as_distro_details_set_id (distro, g_value_get_string (value));
-			break;
-		case AS_DISTRO_DETAILS_NAME:
-			as_distro_details_set_name (distro, g_value_get_string (value));
-			break;
-		case AS_DISTRO_DETAILS_VERSION:
-			as_distro_details_set_version (distro, g_value_get_string (value));
+		case AS_DISTRO_DETAILS_HOMEPAGE:
+			g_value_set_string (value, as_distro_details_get_homepage (distro));
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -310,7 +310,6 @@ as_distro_details_class_init (AsDistroDetailsClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	object_class->finalize = as_distro_details_finalize;
 	object_class->get_property = as_distro_details_get_property;
-	object_class->set_property = as_distro_details_set_property;
 
 	g_object_class_install_property (object_class,
 						AS_DISTRO_DETAILS_ID,
@@ -321,6 +320,9 @@ as_distro_details_class_init (AsDistroDetailsClass *klass)
 	g_object_class_install_property (object_class,
 						AS_DISTRO_DETAILS_VERSION,
 						g_param_spec_string ("version", "version", "version", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (object_class,
+						AS_DISTRO_DETAILS_HOMEPAGE,
+						g_param_spec_string ("homepage", "homepage", "homepage", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 /**
@@ -337,3 +339,19 @@ as_distro_details_new (void)
 	distro = g_object_new (AS_TYPE_DISTRO_DETAILS, NULL);
 	return AS_DISTRO_DETAILS (distro);
 }
+
+
+/**
+ * as_get_current_distro_component_id:
+ *
+ * Returns the component-ID of the current distribution based on contents
+ * of the `/etc/os-release` file.
+ * This function is a shorthand for %as_distro_details_get_cid
+ */
+gchar*
+as_get_current_distro_component_id (void)
+{
+	g_autoptr(AsDistroDetails) distro = as_distro_details_new ();
+	return g_strdup (as_distro_details_get_cid (distro));
+
+}
