@@ -44,6 +44,7 @@ G_BEGIN_DECLS
  * @AS_URL_KIND_HELP:		Help manual
  * @AS_URL_KIND_DONATION:	Page with information about how to donate to the project
  * @AS_URL_KIND_TRANSLATE:	Page with instructions on how to translate the project / submit translations.
+ * @AS_URL_KIND_CONTACT:	Contact the developers
  *
  * The URL type.
  **/
@@ -55,6 +56,7 @@ typedef enum {
 	AS_URL_KIND_HELP,
 	AS_URL_KIND_DONATION,
 	AS_URL_KIND_TRANSLATE,
+	AS_URL_KIND_CONTACT,
 	/*< private >*/
 	AS_URL_KIND_LAST
 } AsUrlKind;
